@@ -146,6 +146,7 @@ class WindowTitle extends St.BoxLayout {
         this._icon = new St.Bin({ style_class: 'window-button-icon' });
         this.add(this._icon);
         this.label_actor = new St.Label({ y_align: Clutter.ActorAlign.CENTER });
+        this.label_actor.clutter_text.single_line_mode = true;
         this.add(this.label_actor);
 
         this._textureCache = St.TextureCache.get_default();
@@ -701,7 +702,7 @@ class WindowList extends St.Widget {
             x_expand: true,
             y_expand: true,
         });
-        box.add(this._windowList, { expand: true });
+        box.add_child(this._windowList);
 
         this._windowList.connect('style-changed', () => {
             let node = this._windowList.get_theme_node();
@@ -714,7 +715,7 @@ class WindowList extends St.Widget {
         box.add(indicatorsBox);
 
         this._workspaceIndicator = new WorkspaceIndicator();
-        indicatorsBox.add(this._workspaceIndicator.container, { expand: false, y_fill: true });
+        indicatorsBox.add_child(this._workspaceIndicator.container);
 
         this._mutterSettings = new Gio.Settings({ schema_id: 'org.gnome.mutter' });
         this._workspacesOnlyOnPrimaryChangedId = this._mutterSettings.connect(
